"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loader;

var _loaderUtils = require("loader-utils");

var _schemaUtils = _interopRequireDefault(require("schema-utils"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function processSource(source, options = {}) {
  const fromURL = options.from;
  const toURL = options.to;
  const mode = options.mode || 'production';
  const env = options.env || 'production';
  const NODE_ENV = process.env && process.env.NODE_ENV || '';
  const WEBPACK_MODE = process.env && process.env.WEBPACK_MODE || '';

  if (!fromURL || !toURL) {
    throw new Error(`Must set 'from' and 'to' options!`);
  } else if (!(0, _utils.isUrl)(fromURL) || !(0, _utils.isUrl)(toURL)) {
    throw new Error(`Cannot transform ${options.from} to ${options.to}!`);
  }

  if (NODE_ENV === env || WEBPACK_MODE === mode) {
    const regex = new RegExp(`url\\(\\s*${fromURL.replace(/\//g, '\\/')}`, 'g');
    const regexWithSingleQuotes = new RegExp(`url\\(\\s*'${fromURL.replace(/\//g, '\\/')}`, 'g');
    const regexWithDoubleQuotes = new RegExp(`url\\(\\s*"${fromURL.replace(/\//g, '\\/')}`, 'g');
    return source.replace(regex, `url(${toURL}`).replace(regexWithSingleQuotes, `url('${toURL}`).replace(regexWithDoubleQuotes, `url("${toURL}`);
  }

  return source;
}

const schema = {
  type: 'object',
  properties: {
    from: {
      type: 'string'
    },
    to: {
      type: 'string'
    },
    mode: {
      type: 'string'
    },
    env: {
      type: 'string'
    }
  }
};

function loader(source) {
  const options = (0, _loaderUtils.getOptions)(this);
  (0, _schemaUtils.default)(schema, options, 'css-url-loader');
  const processedSource = processSource(source, options);
  return processedSource;
}